@@ -52,7 +52,7 @@ class A6HttpCallHandlerTest {
     private PrintStream console = null;
     private ByteArrayOutputStream bytes = null;
 
-    HTTPReqCallHandler httpReqCallHandler;
+    RpcCallHandler rpcCallHandler;
 
     Cache<Long, A6Conf> cache;
 
@@ -99,8 +99,8 @@ class A6HttpCallHandlerTest {
                     }
                 }
 
-                if (!Objects.isNull(request.getHeader())) {
-                    for (Map.Entry<String, String> header : request.getHeader().entrySet()) {
+                if (!Objects.isNull(request.getHeaders())) {
+                    for (Map.Entry<String, String> header : request.getHeaders().entrySet()) {
                         System.out.println("do filter: header key: " + header.getKey());
                         System.out.println("do filter: header value: " + header.getValue());
                     }
@@ -175,8 +175,8 @@ class A6HttpCallHandlerTest {
         confToken = response.getConfToken();
 
         prepareConfHandler = new PrepareConfHandler(cache, filters);
-        httpReqCallHandler = new HTTPReqCallHandler(cache);
-        channel = new EmbeddedChannel(new BinaryProtocolDecoder(), prepareConfHandler, httpReqCallHandler);
+        rpcCallHandler = new RpcCallHandler(cache);
+        channel = new EmbeddedChannel(new BinaryProtocolDecoder(), prepareConfHandler, rpcCallHandler);
     }
 
     @AfterEach
